from Tkinter import * 
import time 
from math import sin, cos, pi

class AnalogClock:

    def __init__(self, master, size=500):
        self.master = master 
        bg = master['background'] 
        self.canvas = c = Canvas(master, width=size, height=size,
            background=bg, highlightbackground=bg)
        c.pack() 
        self.origin = (size*0.5, size*0.5)
        self.canvas.create_oval(11, 11, size-10, size-10, width=10,
            fill='green')
        self.little = self.create_hand(size*0.35, 7, 'blue') 
        self.big = self.create_hand(size*0.4, 5) 
        self.seconds = self.create_hand(size*0.41, 2, 'red') 
        self.update()

    def create_hand(self, size, width, color='black'):
        ox, oy = self.origin 
        item = self.canvas.create_line(ox, oy, ox+size, oy,
            width=width, fill=color)
        return item, size, width

    def update(self):
        try:
            t = time.time() 
            year, month, day, hh, mm, ss, wday, yday, isdst = \
                time.localtime(t) 
            self.update_hand(self.little, hh%12*5 + mm/12) 
            self.update_hand(self.big, mm)
            self.update_hand(self.seconds, ss)
            self.master.after(int(1000*(1-t%1)), self.update) 
        except TclError:
            # We may get here if the widget is deleted.  
            pass

    def update_hand(self, (item, size, width), minutes):
        degrees = 6*minutes 
        angle = degrees*pi*2/360 
        ox, oy = self.origin 
        x = ox + size*sin(angle) 
        y = oy - size*cos(angle)
        self.canvas.coords(item, ox, oy, x, y)

if __name__ == '__main__':
    root = Tk(); frame = Frame(root); frame.pack() 
    clock = AnalogClock(frame) 
    root.mainloop()
